@@ -28,7 +28,7 @@ try:
 except ImportError:
     raise ImportError(
         "aicspylibczi is required for this reader. "
-        "Install with `pip install aicsimageio[czi]`"
+        "Install with `pip install aicspylibczi>=3.0.5"
     )
 
 ###############################################################################
@@ -74,12 +74,18 @@ class CziReader(Reader):
 
     Notes
     -----
-    To use this reader, install with: `pip install aicsimageio[czi]`.
+    To use this reader, install with: `pip install aicspylibczi>=3.0.5`.
     """
 
     @staticmethod
     def _is_supported_image(fs: AbstractFileSystem, path: str, **kwargs: Any) -> bool:
         try:
+            if not isinstance(fs, LocalFileSystem):
+                raise ValueError(
+                    f"Cannot read CZIs from non-local file system. "
+                    f"Received URI: {path}, which points to {type(fs)}."
+                )
+
             with fs.open(path) as open_resource:
                 CziFile(open_resource)
                 return True
